boofun.core.io
==============

.. automodule:: boofun.core.io


   .. rubric:: Functions

   .. autosummary::

      detect_format
      load
      load_bf
      load_dimacs_cnf
      load_json
      save
      save_bf
      save_dimacs_cnf
      save_json

   .. rubric:: Exceptions

   .. autosummary::

      FileIOError
